import os
import json
import openai
import tenacity
from termcolor import colored


model = "gpt-4-0613"

# make sure to provide some content and ask for keywords for that content in your user_input
# if you want a list returned then specify the "type" as "array" and items as "string

@tenacity.retry(wait=tenacity.wait_exponential(multiplier=1, min=4, max=10),    stop=tenacity.stop_after_attempt(5),    reraise=True,)
def return_code(model, user_input):
    
    
    response = openai.ChatCompletion.create(
        model=model,
        messages=[{"role": "system", "content": "You are a helpful assistant"},
            {"role": "user", "content": f"{user_input}"}],
        # stream=True,
        functions=[
            {
                "name": "extract_essential_keywords_from_user_input",
                "description": "This function takes in  essential keywords extracted from the user input",
                "parameters": {
                    "type": "object",
                    "properties": {
                        "keywords" : {
                            "type": "array",
                            "items": {
                                "type": "string",
                                "description": "list of names of the keywords based on user input",
                    },
                },
            },
                    "required": ["keywords"],
                    }
            }
            

        ],
        function_call="auto"

    )

    message = response.choices[0].message
    

    if message.get("function_call"):
        function_args = json.loads(message["function_call"]["arguments"]) 
        return function_args
    
    if message["content"]:
        print(colored(message["content"], "green"))


print(colored("\nuser input: ", "green"))
user_input = ''
while True:
    line = input()
    if line.strip().lower() == 'done':
        break
    user_input += line + '\n'

function_args = return_code(model, user_input)
result = function_args["keywords"]
for item in result:
    print(colored(item, "green"))